@@ -7,6 +7,7 @@ class SphinxModelAdmin(ModelAdmin):
     weights = None
     # This is a hack
     search_fields = ['pk']
+    actions = None
     
     def queryset(self, request):
         return SphinxQuerySet(
@@ -68,9 +69,12 @@ class SphinxChangeList(ChangeList):
             qs = qs.order_by('%s%s' % ((self.order_type == 'desc' and '-' or ''), self.order_field))
 
         if self.query:
-            print self.query
             qs = qs.query(self.query)
 
+        if not (lookup_params or self.query):
+            # We don't show bare result sets in Sphinx
+            return qs.none()
+
         return qs
     
     def get_results(self, request):
