@@ -6,6 +6,7 @@ import warnings
 import operator
 import apis.current as sphinxapi
 import logging
+import re
 try:
     import decimal
 except ImportError:
@@ -329,7 +330,12 @@ class SphinxQuerySet(object):
     # keep things looking/working generally the same
     def all(self):
         return self
-
+    
+    def none(self):
+        c = EmptySphinxQuerySet()
+        c.__dict__.update(self.__dict__.copy())
+        return c
+        
     # only works on attributes
     def exclude(self, **kwargs):
         filters = self._excludes.copy()
@@ -341,20 +347,27 @@ class SphinxQuerySet(object):
             filters.setdefault(k, []).extend(map(to_sphinx, v))
         return self._clone(_excludes=filters)
 
+    def escape(self, value):
+        return re.sub(r"([=\(\)|\-!@~\"&/\\\^\$\=])", r"\\\1", value)
+
     # you cannot order by @weight (it always orders in descending)
     # keywords are @id, @weight, @rank, and @relevance
-    def order_by(self, *args):
-        sort_by = []
-        for arg in args:
-            sort = 'ASC'
-            if arg[0] == '-':
-                arg = arg[1:]
-                sort = 'DESC'
-            if arg == 'id':
-                arg = '@id'
-            sort_by.append('%s %s' % (arg, sort))
+    def order_by(self, *args, **kwargs):
+        mode = kwargs.pop('mode', sphinxapi.SPH_SORT_EXTENDED)
+        if mode == sphinxapi.SPH_SORT_EXTENDED:
+            sort_by = []
+            for arg in args:
+                sort = 'ASC'
+                if arg[0] == '-':
+                    arg = arg[1:]
+                    sort = 'DESC'
+                if arg == 'id':
+                    arg = '@id'
+                sort_by.append('%s %s' % (arg, sort))
+        else:
+            sort_by = args
         if sort_by:
-            return self._clone(_sort=(sphinxapi.SPH_SORT_EXTENDED, ', '.join(sort_by)))
+            return self._clone(_sort=(mode, ', '.join(sort_by)))
         return self
                     
     # pass these thru on the queryset and let django handle it
@@ -650,6 +663,10 @@ class SphinxQuerySet(object):
             c += 1
         return passages
 
+class EmptySphinxQuerySet(SphinxQuerySet):
+    def _get_sphinx_results(self):
+        return None
+
 class SphinxModelManager(object):
     def __init__(self, model, **kwargs):
         self.model = model
@@ -665,6 +682,9 @@ class SphinxModelManager(object):
     def all(self):
         return self._get_query_set()
     
+    def none(self):
+        return self._get_query_set().none()
+    
     def filter(self, **kwargs):
         return self._get_query_set().filter(**kwargs)
     
@@ -702,7 +722,6 @@ class SphinxSearch(object):
     
     def __get__(self, instance, model, **kwargs):
         if instance:
-            print instance
             return SphinxInstanceManager(instance, self._index)
         return self._sphinx
     
